@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-
 from django.db import connections, models
 from django.db.models.sql.compiler import SQLCompiler
 from django.db.models.sql.query import Query
@@ -142,11 +140,18 @@ class TreeCompiler(SQLCompiler):
 
         if "__tree" not in self.query.extra_tables:  # pragma: no branch - unlikely
             tree_params = params.copy()
+
             # use aliased table name (U0, U1, U2)
             base_table = self.query.__dict__.get("base_table")
             if base_table is not None:
                 tree_params["db_table"] = base_table
 
+            # When using tree queries in subqueries our base table may use
+            # an alias. Let's hope using the first alias is correct.
+            aliases = self.query.table_map.get(tree_params["db_table"])
+            if aliases:
+                tree_params["db_table"] = aliases[0]
+
             self.query.add_extra(
                 # Do not add extra fields to the select statement when it is a
                 # summary query
@@ -170,7 +175,7 @@ class TreeCompiler(SQLCompiler):
                 ),
             )
 
-        sql = super(TreeCompiler, self).as_sql(*args, **kwargs)
+        sql = super().as_sql(*args, **kwargs)
         if self.connection.vendor == "postgresql":
             CTE = (
                 self.CTE_POSTGRESQL_WITH_INTEGER_ORDERING
@@ -184,7 +189,7 @@ class TreeCompiler(SQLCompiler):
         return ("".join([CTE.format(**params), sql[0]]), sql[1])
 
     def get_converters(self, expressions):
-        converters = super(TreeCompiler, self).get_converters(expressions)
+        converters = super().get_converters(expressions)
         for i, expression in enumerate(expressions):
             # We care about tree fields and annotations only
             if not hasattr(expression, "sql"):
